@@ -5,13 +5,17 @@
 //! data on *n*-dimensional arrays (ndarray).
 //!
 //! ndrustfft provides Handler structs for FFT's and DCTs, which must be provided alongside
-//! with the arrays to the respective function (see below) .
+//! with the arrays to the respective functions (see below) .
 //! The Handlers implement a process function, which is a wrapper around Rustfft's
-//! process function with additional functionality.
+//! process.
 //! Transforms along the outermost axis are in general the fastest, while transforms along
-//! other axis' will create temporary copies of the input array.
+//! other axis' will temporarily create copies of the input array.
 //!
-//! ## Implemented transforms
+//! ## Parallel
+//! The library ships all functions with a parallel version
+//! which leverages the parallel iterators of the ndarray crate.
+//!
+//! ## Available transforms
 //! ### Complex-to-complex
 //! - `fft` : [`ndfft`], [`ndfft_par`]
 //! - `ifft`: [`ndifft`],[`ndifft_par`]
@@ -25,10 +29,6 @@
 //! - `dct3`: [`nddct3`],[`nddct3_par`]
 //! - `dct4`: [`nddct4`],[`nddct4_par`]
 //!
-//! ## Parallel
-//! The library ships all functions with a parallel version
-//! which leverages the parallel abilities of ndarray.
-//!
 //! ## Example
 //! 2-Dimensional real-to-complex fft along first axis
 //! ```
@@ -49,8 +49,16 @@
 //!     0,
 //! );
 //! ```
+//!
+//! # Versions
+//! - v0.3.0: Upgrade `RealFft` to 3.0.0 and `RustDCT` to 0.7
+//! - \>= v0.2.2:
+//!
+//! The first and last elements of real-to-complex transforms are
+//! per definition purely real. This is now enforced actively, by
+//! setting the complex part to zero - similar to numpys rfft.
 #![warn(missing_docs)]
-#![warn(missing_doc_code_examples)]
+#![warn(rustdoc::missing_doc_code_examples)]
 extern crate ndarray;
 extern crate rustfft;
 use ndarray::{Array1, ArrayBase, Dimension, Zip};
@@ -102,14 +110,13 @@ macro_rules! create_transform {
                         handler.$p(&x.to_vec(), outvec.as_slice_mut().unwrap());
                         y.assign(&outvec);
                     });
-                input.swap_axes(outer_axis, axis);
                 output.swap_axes(outer_axis, axis);
             }
         }
     };
 }
 
-/// Similar to create_transform, but supports parallel computation.
+/// Similar to ``create_transform``, but supports parallel computation.
 macro_rules! create_transform_par {
     ($(#[$meta:meta])* $i: ident, $a: ty, $b: ty, $h: ty, $p: ident) => {
         $(#[$meta])*
@@ -143,7 +150,6 @@ macro_rules! create_transform_par {
                         handler.$p(&x.to_vec(), outvec.as_slice_mut().unwrap());
                         y.assign(&outvec);
                     });
-                input.swap_axes(outer_axis, axis);
                 output.swap_axes(outer_axis, axis);
             }
         }
@@ -182,10 +188,8 @@ macro_rules! create_transform_par {
 #[derive(Clone)]
 pub struct FftHandler<T> {
     n: usize,
-    m: usize,
     plan_fwd: Arc<dyn Fft<T>>,
     plan_bwd: Arc<dyn Fft<T>>,
-    buffer: Vec<Complex<T>>,
 }
 
 impl<T: FftNum> FftHandler<T> {
@@ -209,13 +213,10 @@ impl<T: FftNum> FftHandler<T> {
         let mut planner = FftPlanner::<T>::new();
         let fwd = planner.plan_fft_forward(n);
         let bwd = planner.plan_fft_inverse(n);
-        let buffer = vec![Complex::zero(); n];
         FftHandler::<T> {
             n,
-            m: n / 2 + 1,
             plan_fwd: Arc::clone(&fwd),
             plan_bwd: Arc::clone(&bwd),
-            buffer,
         }
     }
 
@@ -430,6 +431,12 @@ impl<T: FftNum> R2cFftHandler<T> {
             a.re = b.re * n64;
             a.im = b.im * n64;
         }
+        // First element must be real
+        indata[0].im = T::zero();
+        // If original vector is even, last element must be real
+        if self.n % 2 == 0 {
+            indata[self.m - 1].im = T::zero();
+        }
         self.plan_bwd.process(&mut indata, out).unwrap();
     }
 
@@ -875,6 +882,40 @@ mod test {
         approx_eq(&v, &v_copy);
     }
 
+    #[test]
+    fn test_ifft_c2r_first_last_element() {
+        let n = 6;
+        let mut v = Array1::<f64>::zeros(n);
+        let mut vhat = Array1::<Complex<f64>>::zeros(n / 2 + 1);
+        let solution_numpy_first_elem: Array1<f64> =
+            array![0.16667, 0.16667, 0.16667, 0.16667, 0.16667, 0.16667];
+        let solution_numpy_last_elem: Array1<f64> =
+            array![0.16667, -0.16667, 0.16667, -0.16667, 0.16667, -0.16667];
+        let mut rfft_handler = R2cFftHandler::<f64>::new(n);
+
+        // First element should be purely real, thus the imaginary
+        // part should not matter. However, original realfft gives
+        // different results for different imaginary parts
+        vhat[0].re = 1.;
+        vhat[0].im = 100.;
+        // backward
+        ndifft_r2c(&vhat, &mut v, &mut rfft_handler, 0);
+        // assert
+        approx_eq(&v, &solution_numpy_first_elem);
+
+        // Same for last element, if input is even
+        for v in vhat.iter_mut() {
+            v.re = 0.;
+            v.im = 0.;
+        }
+        vhat[3].re = 1.;
+        vhat[3].im = 100.;
+        // backward
+        ndifft_r2c(&vhat, &mut v, &mut rfft_handler, 0);
+        // assert
+        approx_eq(&v, &solution_numpy_last_elem);
+    }
+
     #[test]
     fn test_dct1() {
         // Solution from scipy.fft.dct(x, type=1)
